.. Johnny Can Encrypt documentation master file, created by
   sphinx-quickstart on Wed Jul  8 18:19:32 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Johnny Can Encrypt's documentation!
==============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
